import{d as s,a5 as m,z as n,X as e,c as l,g as c,f as u,b as f}from"./index-a1b8d248.js";import{I as h}from"./ItemsListing-08846369.js";import"./VCheckbox-5797eb11.js";import"./eventbus-142801ce.js";import"./VListItem-99589506.js";import"./VCheckboxBtn-b34ea085.js";import"./VList-db9ad95c.js";import"./VCardText-426e9876.js";import"./VCard-62364c90.js";import"./VMenu-a4b04473.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-8ce3726a.js";import"./Button-36db0a16.js";import"./VSpacer-c665d1ef.js";/* empty css              */import"./PanelviewItemCompact-412c96c5.js";import"./VAlert-11c8d9d0.js";import"./Container-6ba8cd4d.js";import"./Toolbar-e7daca02.js";import"./VToolbar-69b0039c.js";import"./VTextField-11675678.js";import"./VInfiniteScroll-b88bd748.js";import"./layout-2c6f8b0d.js";import"./VVirtualScroll-abd3c2c6.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{J as default};
